=====================
Configuration Options
=====================

The following is an overview of all available configuration options in Tacker.
For a sample configuration file, refer to :doc:`/configuration/sample_config`.

.. show-options::
   :config-file: etc/config-generator.conf
